@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::DAGOLDEN;
-our $VERSION = '0.048'; # VERSION
+our $VERSION = '0.049'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -15,8 +15,8 @@ use Dist::Zilla 4.3; # authordeps
 use Dist::Zilla::PluginBundle::Filter ();
 use Dist::Zilla::PluginBundle::Git 1.121010 ();
 
-use Dist::Zilla::Plugin::AutoMetaResources      ();
 use Dist::Zilla::Plugin::Authority 1.006 ();
+use Dist::Zilla::Plugin::Bugtracker 1.110 ();
 use Dist::Zilla::Plugin::CheckChangesHasContent ();
 use Dist::Zilla::Plugin::CheckExtraTests        ();
 use Dist::Zilla::Plugin::CheckMetaResources 0.001  ();
@@ -24,6 +24,7 @@ use Dist::Zilla::Plugin::CheckPrereqsIndexed 0.002 ();
 use Dist::Zilla::Plugin::ContributorsFromGit 0.004 ();
 use Dist::Zilla::Plugin::CopyFilesFromBuild ();
 use Dist::Zilla::Plugin::Git::NextVersion   ();
+use Dist::Zilla::Plugin::GithubMeta 0.36 ();
 use Dist::Zilla::Plugin::InsertCopyright 0.001 ();
 use Dist::Zilla::Plugin::MetaNoIndex ();
 use Dist::Zilla::Plugin::MetaProvides::Package 1.14 (); # hides DB/main/private packages
@@ -32,7 +33,7 @@ use Dist::Zilla::Plugin::OurPkgVersion 0.004 (); # TRIAL comment support
 use Dist::Zilla::Plugin::PodWeaver ();
 use Dist::Zilla::Plugin::ReadmeAnyFromPod 0.120051 ();
 use Dist::Zilla::Plugin::TaskWeaver 0.101620       ();
-use Dist::Zilla::Plugin::Test::Compile 2.022     ();
+use Dist::Zilla::Plugin::Test::Compile 2.023     ();
 use Dist::Zilla::Plugin::Test::MinimumVersion 2.000003 ();
 use Dist::Zilla::Plugin::Test::Perl::Critic ();
 use Dist::Zilla::Plugin::Test::PodSpelling 2.006000 (); # x_contributor support
@@ -156,6 +157,15 @@ has weaver_config => (
     default => sub { $_[0]->payload->{weaver_config} || '@DAGOLDEN' },
 );
 
+has github_issues => (
+    is      => 'ro',
+    isa     => 'Str',
+    lazy    => 1,
+    default => sub {
+        exists $_[0]->payload->{git_issues} ? $_[0]->payload->{git_issues} : 1;
+    },
+);
+
 has git_remote => (
     is      => 'ro',
     isa     => 'Str',
@@ -282,12 +292,21 @@ sub configure {
         ],
         [ 'MetaProvides::Package' => { meta_noindex => 1 } ], # AFTER MetaNoIndex
         [
-            AutoMetaResources => {
-                'repository.github' => 'user:dagolden',
-                'bugtracker.rt'     => 1,
-                'homepage'          => 'https://metacpan.org/release/%{dist}',
+            GithubMeta => {
+                user   => 'dagolden',
+                remote => [ qw(origin github) ],
+                issues => $self->github_issues,
             }
         ],
+        (
+            ($self->github_issues && ! $self->no_git)
+            ? ()
+            : (
+                # fake out Pod::Weaver::Section::Support
+                [ 'Bugtracker' => { mailto => '' } ],
+                [ 'MetaResources' => { map {; "repository.$_" => "http://localhost/" } qw/url web/ } ],
+              )
+        ),
 
         'MetaYAML',                                           # core
         'MetaJSON',                                           # core
@@ -384,7 +403,7 @@ Dist::Zilla::PluginBundle::DAGOLDEN - Dist::Zilla configuration the way DAGOLDEN
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 SYNOPSIS
 
@@ -461,10 +480,11 @@ following dist.ini:
    directory = corpus
    package = DB        ; just in case
  
-   [AutoMetaResources] ; set META resources
-   bugtracker.rt      = 1
-   repository.github  = user:dagolden
-   homepage           = https://metacpan.org/release/%{dist}
+   [GithubMeta]        ; set META resources
+   user = dagolden
+   remote = origin
+   remote = github
+   issues = 1
  
    [MetaProvides::Package] ; add 'provides' to META files
    meta_noindex = 1        ; respect prior no_index directives
@@ -539,8 +559,27 @@ Default is 0.
 
 =item *
 
-C<<< auto_prereq >>> -- this indicates whether AutoPrereq should be used or not.
-Default is 1.
+C<<< authority >>> -- specifies the x_authority field for pause.  Defaults to 'cpan:DAGOLDEN'.
+
+=item *
+
+C<<< auto_prereq >>> -- this indicates whether AutoPrereq should be used or not.  Default is 1.
+
+=item *
+
+C<<< fake_release >>> -- swaps FakeRelease for UploadToCPAN. Mostly useful for testing a dist.ini without risking a real release.
+
+=item *
+
+C<<< git_remote >>> -- where to push after release
+
+=item *
+
+C<<< github_issues >>> -- whether to use github issue tracker. Defaults is 1.
+
+=item *
+
+C<<< stopwords >>> -- add stopword for Test::PodSpelling (can be repeated)
 
 =item *
 
@@ -550,25 +589,12 @@ C<<< Git::NextVersion >>>
 
 =item *
 
-C<<< version_regexp >>> -- given to C<<< Git::NextVersion >>>.  Default
-is '^release-(.+)$'
-
-=item *
-
-C<<< fake_release >>> -- swaps FakeRelease for UploadToCPAN. Mostly useful for
-testing a dist.ini without risking a real release.
-
-=item *
-
 C<<< weaver_config >>> -- specifies a Pod::Weaver bundle.  Defaults to @DAGOLDEN.
 
 =item *
 
-C<<< authority >>> -- specifies the x_authority field for pause.  Defaults to 'cpan:DAGOLDEN'.
-
-=item *
-
-C<<< stopwords >>> -- add stopword for Test::PodSpelling (can be repeated)
+C<<< version_regexp >>> -- given to C<<< Git::NextVersion >>>.  Default
+is '^release-(.+)$'
 
 =item *
 
@@ -645,7 +671,7 @@ L<Dist::Zilla::Plugin::TaskWeaver>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-DAGOLDEN>.
+at L<https://github.com/dagolden/dist-zilla-pluginbundle-dagolden/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -655,7 +681,7 @@ public review and contribution under the terms of the license.
 
 L<https://github.com/dagolden/dist-zilla-pluginbundle-dagolden>
 
-  git clone git://github.com/dagolden/dist-zilla-pluginbundle-dagolden.git
+  git clone https://github.com/dagolden/dist-zilla-pluginbundle-dagolden.git
 
 =head1 AUTHOR
 
